@@ -3,7 +3,7 @@ import os
 import threading
 from typing import List
 
-from maitai._config_listener_thread import ConfigListenerThread
+from maitai._config_listener import ConfigListener
 from maitai._maitai_client import MaitaiClient
 from maitai.models.application import Application
 from maitai.models.config import Config as ActionConfig
@@ -21,7 +21,7 @@ class Config(MaitaiClient):
         self._api_key = None
         self._company_id = None
         self.websocket_listener_thread = None
-        self.config_listener_thread = None
+        self.config_listener = None
         self._application_action_configs: dict[str, dict[str, ActionConfig]] = {}
         self.initialized = False
         self.auth_keys: KeyMap = KeyMap(
@@ -30,6 +30,7 @@ class Config(MaitaiClient):
             anthropic_api_key=Key(id=-1, key_value=os.environ.get("ANTHROPIC_API_KEY")),
             cerebras_api_key=Key(id=-1, key_value=os.environ.get("CEREBRAS_API_KEY")),
             sambanova_api_key=Key(id=-1, key_value=os.environ.get("SAMBANOVA_API_KEY")),
+            gemini_api_key=Key(id=-1, key_value=os.environ.get("GEMINI_API_KEY")),
         )
         self.refresh_interval = 30 * 60  # 30 minutes in seconds
 
@@ -161,22 +162,14 @@ class Config(MaitaiClient):
                     )
 
     def _initialize_websocket(self):
-        self.config_listener_thread = ConfigListenerThread(
+        self.config_listener = ConfigListener(
             self, self.maitai_ws, "APPLICATION_CONFIG_CHANGE", self._company_id
         )
-        self.config_listener_thread.daemon = True
-        self.config_listener_thread.start()
+        self.config_listener.start()
 
     def cleanup(self):
-        if self.config_listener_thread:
-            self.config_listener_thread.terminate()
-            try:
-                self.config_listener_thread.join(
-                    timeout=1.0
-                )  # Give thread time to cleanup
-            except Exception:
-                pass  # If join fails, continue with cleanup
-            self.config_listener_thread = None
+        if self.config_listener:
+            self.config_listener.stop()
 
         if self.refresh_timer:
             self.refresh_timer.cancel()
