@@ -1,4 +1,5 @@
 import asyncio
+import logging
 import os
 import time
 import uuid
@@ -47,6 +48,8 @@ from maitai.models.key import Key
 from maitai.models.metric import RequestTimingMetric
 from maitai.tools import Tools
 
+logger = logging.getLogger("maitai")
+
 DEFAULT_MAX_RETRIES = 2
 
 
@@ -61,6 +64,7 @@ class MaitaiAsync:
         anthropic_api_key: Optional[str] = None,
         cerebras_api_key: Optional[str] = None,
         sambanova_api_key: Optional[str] = None,
+        gemini_api_key: Optional[str] = None,
         azure_api_key: Optional[str] = None,
         azure_deployment: Optional[str] = None,
         azure_api_version: Optional[str] = None,
@@ -85,7 +89,7 @@ class MaitaiAsync:
             )
         if api_key:
             raise ValueError(
-                "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key"
+                "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key, gemini_api_key"
             )
         if openai_api_key:
             if not config.auth_keys.openai_api_key:
@@ -124,7 +128,15 @@ class MaitaiAsync:
                 )
             else:
                 config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
+        if gemini_api_key:
+            if not config.auth_keys.gemini_api_key:
+                config.auth_keys.gemini_api_key = Key(
+                    key_value=gemini_api_key,
+                )
+            else:
+                config.auth_keys.gemini_api_key.key_value = gemini_api_key
         self._client = None
+        azure_params = None
         if azure_api_key:
             azure_params = AzureParams(
                 endpoint=azure_endpoint,
@@ -221,6 +233,7 @@ class AsyncCompletions:
         metadata: dict = {},
         safe_mode: bool = None,
         fallback_config: FallbackConfig = None,
+        return_request: bool = False,
         # OpenAI Arguments
         messages: Iterable[openai_chat_types.ChatCompletionMessageParam],
         model: Union[str, openai_types.ChatModel, openai.NotGiven] = openai.NOT_GIVEN,
@@ -238,6 +251,7 @@ class AsyncCompletions:
         max_completion_tokens: Union[Optional[int], openai.NotGiven] = openai.NOT_GIVEN,
         n: Union[Optional[int], openai.NotGiven] = openai.NOT_GIVEN,
         presence_penalty: Union[Optional[float], openai.NotGiven] = openai.NOT_GIVEN,
+        reasoning_effort: Optional[str] = openai.NOT_GIVEN,
         response_format: Union[
             openai_chat_types.completion_create_params.ResponseFormat, openai.NotGiven
         ] = openai.NOT_GIVEN,
@@ -377,6 +391,7 @@ class AsyncCompletions:
             user=user,
             parallel_tool_calls=parallel_tool_calls,
             extra_headers=extra_headers,
+            reasoning_effort=reasoning_effort,
         )
         if server_side_inference:
             response_timeout = None
@@ -399,6 +414,7 @@ class AsyncCompletions:
                 "auth_keys": config.auth_keys.model_dump(),
                 "metadata": metadata,
                 "safe_mode": safe_mode,
+                "return_request": return_request,
             }
 
             if self._client_params is not None:
@@ -451,7 +467,7 @@ class AsyncCompletions:
                     raise e
                 if safe_mode:
                     raise e
-                print("Maitai issue, retrying on client side")
+                logger.warning("Maitai issue, retrying on client side")
                 server_side_inference = False
         if not server_side_inference:
             if "openai:" in model:
@@ -478,6 +494,7 @@ class AsyncCompletions:
                 max_tokens=max_tokens,
                 n=n,
                 presence_penalty=presence_penalty,
+                reasoning_effort=reasoning_effort,
                 response_format=response_format,
                 seed=seed,
                 stop=stop,
@@ -533,7 +550,7 @@ class AsyncCompletions:
                         metadata=metadata,
                     )
                 else:
-                    self.inference_client.store_chat_response_async(
+                    await self.inference_client.store_chat_response_async(
                         session_id=session_id,
                         reference_id=reference_id,
                         intent=intent,
@@ -598,7 +615,7 @@ class AsyncCompletions:
                 metadata=metadata,
             )
         else:
-            self.inference_client.store_chat_response_async(
+            await self.inference_client.store_chat_response_async(
                 session_id=session_id,
                 reference_id=reference_id,
                 intent=intent,
@@ -652,7 +669,7 @@ class AsyncCompletions:
                 retry_args["model"] = retry_args["fallback_model"]
             if "gpt" in retry_args.get("model", ""):
                 retry_args["model"] = retry_args["model"].replace("openai:", "")
-                print("Maitai issue, retrying on client side")
+                logger.warning("Maitai issue, retrying on client side")
                 response = await self.create(**retry_args)
                 async for resp in response:
                     yield resp
