@@ -5,6 +5,21 @@ import httpx
 
 from maitai_common.version import version
 
+# Common client settings to ensure consistency
+CLIENT_SETTINGS = {
+    "http2": True,
+    "limits": httpx.Limits(
+        max_keepalive_connections=200,
+        max_connections=1000,
+    ),
+    "timeout": httpx.Timeout(timeout=600, connect=5.0),
+    "follow_redirects": True,
+}
+
+# In _base_client.py, they define DEFAULT_MAX_RETRIES = 2
+# We'll incorporate that into our transport settings
+DEFAULT_MAX_RETRIES = 2
+
 
 def _get_aws_instance_metadata(url, timeout=2):
     try:
@@ -93,37 +108,27 @@ class MaitaiClient:
     def get_client(self):
         if self._client is None:
             self._client = httpx.Client(
-                http2=True,
-                limits=httpx.Limits(
-                    max_keepalive_connections=200,
-                    max_connections=1000,
-                    keepalive_expiry=300,
-                ),
-                transport=httpx.HTTPTransport(retries=3),
+                **CLIENT_SETTINGS,
+                transport=httpx.HTTPTransport(retries=DEFAULT_MAX_RETRIES),
             )
         return self._client
 
     async def get_async_client(self):
         if self._async_client is None:
             self._async_client = httpx.AsyncClient(
-                http2=True,
-                limits=httpx.Limits(
-                    max_keepalive_connections=200,
-                    max_connections=1000,
-                    keepalive_expiry=300,
-                ),
-                transport=httpx.AsyncHTTPTransport(retries=3),
+                **CLIENT_SETTINGS,
+                transport=httpx.AsyncHTTPTransport(retries=DEFAULT_MAX_RETRIES),
             )
         return self._async_client
 
     def cleanup(self):
         try:
             self.executor.shutdown()
-        except Exception as e:
+        except Exception:
             pass
         try:
             self.close_client()
-        except Exception as e:
+        except Exception:
             pass
 
     def close_client(self):
@@ -131,6 +136,11 @@ class MaitaiClient:
             self._client.close()
             self._client = None
 
+    async def close_async_client(self):
+        if self._async_client:
+            await self._async_client.aclose()
+            self._async_client = None
+
     def __del__(self):
         self.cleanup()
 
@@ -176,6 +186,7 @@ class MaitaiClient:
             pass
 
     def init_sdk(self, api_key: str, host: str):
+        """Initialize the SDK and warm up connections."""
         url = f"{host}/config/init_sdk"
         headers = {
             "Content-Type": "application/json",
@@ -183,7 +194,9 @@ class MaitaiClient:
             "User-Agent": version,
         }
 
-        response = httpx.get(url, headers=headers, timeout=15)
+        # Get the shared client to warm up connections
+        client = self.get_client()
+        response = client.get(url, headers=headers, timeout=15)
         if response.status_code != 200:
             raise Exception(f"Failed to initialize Maitai client: {response.text}")
         return response.json()
